@@ -28,6 +28,15 @@ class ScoringFunctionComponentNameEnum:
     LINKER_EFFECTIVE_LENGTH = "linker_effective_length"
     LINKER_GRAPH_LENGTH = "linker_graph_length"
     LINKER_LENGTH_RATIO = "linker_length_ratio"
+    LINKER_NUM_RINGS = "linker_num_rings"
+    LINKER_NUM_ALIPHATIC_RINGS = "linker_num_aliphatic_rings"
+    LINKER_NUM_AROMATIC_RINGS = "linker_num_aromatic_rings"
+    LINKER_NUM_SP_ATOMS = "linker_num_sp_atoms"
+    LINKER_NUM_SP2_ATOMS = "linker_num_sp2_atoms"
+    LINKER_NUM_SP3_ATOMS = "linker_num_sp3_atoms"
+    LINKER_NUM_HBA = "linker_num_hba"
+    LINKER_NUM_HBD = "linker_num_hbd"
+    LINKER_MOL_WEIGHT = "linker_mol_weight"
 
     #NOTE: components below are AZ specific
     AZ_LOGD74 = "az_logd74"
