@@ -10,7 +10,9 @@ from reinvent_scoring.scoring.score_components import TanimotoSimilarity, \
     NumRings, AZlogD74, HLMClint, SlogP, \
     RHClint, HHClint, SolubilityDD, HERG, CACO2Intrinsic, CACO2Efflux, AZdock, RatPKPiP, Top20, GraphLength, \
     NumberOfStereoCenters, \
-    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, DockStream, BuildingBlockAvailabilityComponent, \
+    LinkerLengthRatio, LinkerGraphLength, LinkerEffectiveLength, LinkerNumRings, LinkerNumAliphaticRings, \
+    LinkerNumAromaticRings, LinkerNumSPAtoms, LinkerNumSP2Atoms, LinkerNumSP3Atoms, LinkerNumHBA, \
+    LinkerNumHBD, LinkerMolWeight, DockStream, BuildingBlockAvailabilityComponent, \
     NumAromaticRings, NumAliphaticRings
 from reinvent_scoring.scoring.score_components.console_invoked import AZgard
 from reinvent_scoring.scoring.score_components.pip.pip_log_prediction_component import PiPLogPredictionComponent
@@ -70,6 +72,15 @@ class ScoreComponentFactory:
             enum.LINKER_GRAPH_LENGTH: LinkerGraphLength,
             enum.LINKER_EFFECTIVE_LENGTH: LinkerEffectiveLength,
             enum.LINKER_LENGTH_RATIO: LinkerLengthRatio,
+            enum.LINKER_NUM_RINGS: LinkerNumRings,
+            enum.LINKER_NUM_ALIPHATIC_RINGS: LinkerNumAliphaticRings,
+            enum.LINKER_NUM_AROMATIC_RINGS: LinkerNumAromaticRings,
+            enum.LINKER_NUM_SP_ATOMS: LinkerNumSPAtoms,
+            enum.LINKER_NUM_SP2_ATOMS: LinkerNumSP2Atoms,
+            enum.LINKER_NUM_SP3_ATOMS: LinkerNumSP3Atoms,
+            enum.LINKER_NUM_HBA: LinkerNumHBA,
+            enum.LINKER_NUM_HBD: LinkerNumHBD,
+            enum.LINKER_MOL_WEIGHT: LinkerMolWeight,
             enum.DOCKSTREAM: DockStream,
             enum.AZGARD: AZgard,
             enum.AIZYNTH: BuildingBlockAvailabilityComponent
